@@ -1,5 +1,7 @@
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
+// SPDX-FileCopyrightInfo: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-GPL-2.0-only-with-dune-grid-glue-exception
 
 #ifndef DUNE_GRIDGLUE_OVERLAPPINGMERGE_CC
 #define DUNE_GRIDGLUE_OVERLAPPINGMERGE_CC
@@ -37,7 +39,7 @@ void OverlappingMerge<dim1,dim2,dimworld, T>::computeIntersections(const Dune::G
                                                const std::vector<Dune::FieldVector<T,dimworld> >& grid2ElementCorners,
                                                std::bitset<(1<<dim2)>& neighborIntersects2,
                                                unsigned int grid2Index,
-                                               std::vector<RemoteSimplicialIntersection>& intersections)
+                                               std::vector<SimplicialIntersection>& intersections)
 {
     using std::min;
 
@@ -47,8 +49,8 @@ void OverlappingMerge<dim1,dim2,dimworld, T>::computeIntersections(const Dune::G
     typedef SimplexMethod<dimworld,dim1,dim2,T> CM;
 
 #ifndef NDEBUG
-    const Dune::ReferenceElement<T,dim1>& refElement1 = Dune::ReferenceElements<T,dim1>::general(grid1ElementType);
-    const Dune::ReferenceElement<T,dim2>& refElement2 = Dune::ReferenceElements<T,dim2>::general(grid2ElementType);
+    const auto& refElement1 = Dune::ReferenceElements<T,dim1>::general(grid1ElementType);
+    const auto& refElement2 = Dune::ReferenceElements<T,dim2>::general(grid2ElementType);
 
     // A few consistency checks
     assert((unsigned int)(refElement1.size(dim1)) == grid1ElementCorners.size());
@@ -130,10 +132,10 @@ void OverlappingMerge<dim1,dim2,dimworld, T>::computeIntersections(const Dune::G
             g2local[i] = grid2Geometry.local(P[i]);
         }
 
-        intersections.push_back(RemoteSimplicialIntersection(grid1Index, grid2Index));
+        intersections.emplace_back(grid1Index, grid2Index);
         for (i = 0; i < n_intersectionnodes; ++i) {
-            intersections.back().grid1Local_[0][i] = g1local[i];
-            intersections.back().grid2Local_[0][i] = g2local[i];
+            intersections.back().corners0[0][i] = g1local[i];
+            intersections.back().corners1[0][i] = g2local[i];
         }
 
     } else if (P.size() > n_intersectionnodes) {  // P is a union of simplices of dimension dimis
@@ -172,10 +174,10 @@ void OverlappingMerge<dim1,dim2,dimworld, T>::computeIntersections(const Dune::G
                     g2local[j] = grid2Geometry.local(global[j]);
                 }
 
-                intersections.push_back(RemoteSimplicialIntersection(grid1Index,grid2Index));
+                intersections.emplace_back(grid1Index,grid2Index);
                 for (size_type j = 0; j < n_intersectionnodes; ++j) {
-                    intersections.back().grid1Local_[0][j] = g1local[j];
-                    intersections.back().grid2Local_[0][j] = g2local[j];
+                    intersections.back().corners0[0][j] = g1local[j];
+                    intersections.back().corners1[0][j] = g2local[j];
                 }
             }
         }
